## Harborough District Council - Bin Collection Dates

A (very) small Python library which takes a UPRN within Market Harborough as a parameter, and returns a dictionary with bin types as keys, and next bin collection dates as values.
